@@ -784,6 +784,8 @@
                 widget = this;
             this._super();
 
+            this._currentTlId = null;
+
             this._tracklistOptions = {
                 consume: null,
                 random: null,
@@ -825,7 +827,10 @@
                     widget._getTlTracks(mopidy);
                 });
                 mopidy.on("event:trackPlaybackStarted", function(event) {
-                    widget._updateCurrentTrack(event.tl_track);
+                    widget._updateCurrentTlId(event.tl_track.tlid);
+                });
+                mopidy.playback.getCurrentTlTrack().then(function(tlTrack) {
+                    widget._updateCurrentTlId(tlTrack ? tlTrack.tlid : null);
                 });
                 widget._getTlTracks(mopidy);
                 widget._getTracklistOptions(mopidy);
@@ -834,19 +839,16 @@
 
         _getTlTracks: function(mopidy) {
             var $element = this.element,
-                options = this.options,
+                anchorCallback = this.options.anchorCallback,
                 widget = this;
             mopidy.tracklist.getTlTracks().then(function(tlTracks) {
                 var $items = $.map(tlTracks, function(tlTrack) {
                     return $("<li />", {"data-icon": false})
-                        .append(options.anchorCallback(tlTrack))
+                        .append(anchorCallback(tlTrack))
                         .data("model", tlTrack);
                 });
-                $element.empty().append($items);
-                mopidy.playback.getCurrentTlTrack().then(function(tlTrack) {
-                    widget._updateCurrentTrack(tlTrack);
-                });
-                $element.tracklist("refresh");
+                $element.empty().append($items).tracklist("refresh");
+                widget._updateCurrentTlId(widget._currentTlId);
             });
         },
 
@@ -867,13 +869,13 @@
             });
         },
 
-        _updateCurrentTrack: function(tlTrack) {
-            var tlid = tlTrack ? tlTrack.tlid : null;
+        _updateCurrentTlId: function(tlid) {
             this.element.children("li").each(function() {
                 var $item = $(this),
                     model = $item.data("model");
                 $item.find("a").toggleClass("ui-btn-active", model.tlid === tlid);
             });
+            this._currentTlId = tlid;
         },
 
         _updateTracklistOption: function(key, value) {
